@@ -6,11 +6,17 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+from .accesspolicyidentifier import AccessPolicyIdentifier
 from .organizationidentifier import OrganizationIdentifier
 from .organizationprojectidentfier import OrganizationProjectIdentifier
+from .role import Role
+from .rolelaunchstage import RoleLaunchStage
 
 
 __all__: list[str] = [
+    'AccessPolicyIdentifier',
     'OrganizationIdentifier',
     'OrganizationProjectIdentifier',
+    'Role',
+    'RoleLaunchStage',
 ]
\ No newline at end of file
